//////////////////////////////////////////////////////////////////////////////
//
// top_module
//
// Intended target for Xilinx CoolRunner-II CPLD  (XC2C32A)
//
// Author:  Xilinx, Inc.
//
// Notes:   This is the top level module.  It instantiates i2c_module_mod.v
//
// Date:    04-15-2005
// 
///////////////////////////////////////////////////////////////////////////////

`timescale 1ns/1ps

module top (

//start of i2c block
            pld_i2c_scl,
            pld_i2c_sda,
            pld_i2c_rst,
            gpio_input_pins,
            gpio_output_pins
            );
   

	 
// I2C interface   
   inout         pld_i2c_scl;       // I2C clk input
   inout         pld_i2c_sda;       // I2C data
   input         pld_i2c_rst;       // reset for all FFs in I2C
   input  [7:0]  gpio_input_pins;   // GPIO inputs - read on I2C
   output [7:0]  gpio_output_pins;  // GPIO outputs - write from I2C
   


//*************************************
//I2C Port Expander module
//*************************************

   wire sda_out;
   wire out_en;
   wire ack_out;

   // tri-state output vs. drive 1 for logic 1 (i2c specs pullup)
   wire sda_in = pld_i2c_sda;
   assign pld_i2c_sda = (ack_out || (out_en && ~sda_out)) ? 1'b0 : 1'bz;


i2c_module i2c_module_0 (.scl(pld_i2c_scl), 
                         .i2c_rst(pld_i2c_rst),
                         .sda_in(sda_in),
                         .gpio_input_pins (gpio_input_pins),
                         .ack_out(ack_out),
                         .out_en (out_en),
                         .sda_out (sda_out),
                         .gpio_output_pins (gpio_output_pins));
                         
                          defparam i2c_module_0.my_i2c_addr = 7'b1010110;  // pass via parameter
																									// Define your i2c slave address here



//*********************************************************************
// Instantiate Pullups for Timing Simulation.  
// This allows for simulation of Open Drain (external pullup) behavior
// 
// NOTE:  In order for Timing Simulation to work, 
//        you must also append the top_timesim.v file 
//        with the following:  
//
//         X_PU X_PU1     	
//         (
//             	.O (pld_i2c_sda)
//    	);
//*********************************************************************


PULLUP PULLUP_inst (
	.O(pld_i2c_sda)
	);



endmodule